import argparse
import pytest
from calculate import calculate_sundaram

parser = argparse.ArgumentParser()
parser.add_argument("-t", "--test", dest="test_mod", action="store_true")
parser.add_argument("-d", "--doctest", dest="doctest_mod", action="store_true")
parser.add_argument("value", nargs="?", default=False)

args = parser.parse_args()
help_text = """
Алгоритм для расчёта решета Сундарама

Использование:
    sundaram [верхняя граница]
    sundaram -t [--test]
    sundaram -d [--doctest]

"""


def main():
    """
    Запуск sundarama как скрипта
    """
    if args.test_mod:
        retcode = pytest.main(["-l"])
        print(retcode)
        exit()
    if args.doctest_mod:
        import doctest
        doctest.testfile("test_sundaram.py")
        exit()
    if args.value is False:
        print(help_text)
    try:
        upper_limit = int(args.value)
        if upper_limit <= 1:
            print("Значение должно быть > 1")
            exit()
    except IndexError:
        print("Вы должны передать число")
        print(help_text)
        exit()
    except ValueError:
        print("Значение должно быть числом")
        exit()

    print(f"Расчет решета Сундарама в рамках [2,...,{upper_limit}]")

    print(calculate_sundaram(int(upper_limit)))

    print("Готово!")


if __name__ == "__main__":
    main()




from validate import validate_input

def calculate_sundaram(n):
    '''
    расчёт решета Сундарама

    >>> calculate_sundaram(6)
    [2, 3, 5]
    >>> calculate_sundaram(15)
    [2, 3, 5, 7, 11, 13]

    :return list[int]: решето Сундарама
    '''

    sundaram = validate_input(n)
    if not sundaram:
        return

    f_formula = int((sundaram - 1) / 2)
    marked = [0] * (f_formula + 1)
    for i in range(1, f_formula + 1):
        j = i

        while (i + j + 2 * i * j) <= f_formula:
            marked[i + j + 2 * i * j] = 1
            j += 1

    res_arr = []
    if sundaram > 2:
        res_arr.append(2)

    for i in range(1, f_formula + 1):
        if marked[i] == 0:
            res_arr.append(2 * i + 1)
    
    return res_arr


if __name__ == "__main__":
    import doctest

    doctest.testmod(verbose=True)




from os import path
from setuptools import setup

try:
    current_path = path.abspath(path.dirname(__file__))
except NameError:
    current_path = None
try:
    with open(path.join(current_path, 'README.md'),
              encoding='utf-8') as f:
        long_description = f.read()
except FileNotFoundError:
    long_description = ''
setup(
    name='sundaram',
    version='1.0.1',
    # list folders, not files
    packages=['sundaram',
              'sundaram.test'],
    scripts=['sundaram/bin/sundaram_script.py',
             'sundaram/test/test_sundaram.py'],
    license='MIT License',
    description='Расчет решета сундарама',
    long_description=long_description,
    long_description_content_type='text/markdown'
)



def validate_input(inp):
    '''
    Преобразование 
    вводимых пользователем значений
    и перехват возможных исключений

    :param inp: Входное значение
    :return: int | bool
    '''
    try:
        candidate = int(inp)
        if candidate < 3:
            print('Число < 3')
            return False
        return candidate
    except ValueError:
        print('\nВведено некорректное значение '
              '(n >= 3), попробуйте снова')
        return False


import pytest
from sundaram .calculate import calculate_sundaram

def test_calculate_sundaram():
    res = [2, 3, 5, 7, 11, 13, 17, 19, 23]
    func_res = calculate_sundaram(25)
    assert res == func_res
    


if __name__ == "__main__":
   pytest.main()